@@ -4,6 +4,7 @@ import dataclasses
 import json
 import logging
 import uuid
+from io import BytesIO
 from typing import Any
 from typing import Dict
 from typing import List
@@ -12,6 +13,7 @@ import numpy as np
 import rasterio
 from geopandas import GeoDataFrame as gdf
 from greppo import osm
+from PIL import Image
 from rasterio.io import MemoryFile
 from rasterio.warp import calculate_default_transform
 from rasterio.warp import reproject
@@ -25,6 +27,7 @@ from .input_types import Multiselect
 from .input_types import Number
 from .input_types import Select
 from .input_types import Text
+from .input_types import Display
 from .layers.base_layer import BaseLayer
 from .layers.image_layer import ImageLayer
 from .layers.overlay_layer import OverlayLayer
@@ -43,7 +46,7 @@ class GreppoApp(object):
 
     def __init__(self, title: str = "Untitled App"):
         self.title: str = title
-
+        self.display = Display
         self.select = Select
         self.multiselect = Multiselect
         self.draw_feature = DrawFeature
@@ -85,6 +88,11 @@ class GreppoAppProxy(object):
         # Input updates
         self.inputs = {}
 
+    def display(self, **kwargs):
+        display = Display(**kwargs)
+        self.register_input(display)
+        return display
+
     def number(self, **kwargs):
         number = Number(**kwargs)
         self.register_input(number)
@@ -214,18 +222,25 @@ class GreppoAppProxy(object):
     def image_layer(self, file_path: str, title: str, description: str, visible: bool):
         id = uuid.uuid4().hex
 
-        file_ext = file_path.split(".")[-1]
+        file_ext = file_path.split(".")[-1].lower()
         assert file_ext in [
             "png",
             "jpg",
             "jpeg",
         ], "Image input extension should be png, jpg or jpeg for image_layer"
 
-        src_dataset = rasterio.open(file_path)
+        buffered = BytesIO()
+        image = Image.open(file_path)
+        image.save(buffered, format="JPEG")
+        image_string = base64.b64encode(buffered.getvalue()).decode()
 
-        url = "data:image/png;base64," + base64.b64encode(src_dataset.read()).decode()
+        url = "data:image/png;base64," + image_string
 
         bounds = [[0, 0], [100, 100]]
+        bounds = [
+            [14.760840184106792, 77.97900023926854],
+            [14.763995704693206, 77.98389492733145],
+        ]
 
         self.image_layers.append(
             ImageLayer(id, title, description, url, bounds, visible)
