@@ -1,18 +1,20 @@
 from dataclasses import dataclass
 from typing import Any
+from typing import Dict
+from typing import List
 
 
 @dataclass
 class Dataset:
     label: str
     backgroundColor: str
-    data: list[Any]
+    data: List[Any]
 
 
 @dataclass
 class ChartData:
-    labels: list[Any]
-    datasets: list[Dataset]
+    labels: List[Any]
+    datasets: List[Dataset]
 
 
 # TODO doesn't handle multiple datasets.
@@ -23,10 +25,10 @@ class BarChart:
         name: str,
         title: str,
         description: str,
-        x: list,
-        y: list,
+        x: List,
+        y: List,
         backgroundColor: str = "#000000",
-        input_updates: dict[str, Any] = {},
+        input_updates: Dict[str, Any] = {},
     ):
         self.input_name = name
         self.title = title
