@@ -1,5 +1,7 @@
 from dataclasses import dataclass
 from typing import Any
+from typing import Dict
+from typing import List
 from typing import Optional
 
 
@@ -7,13 +9,13 @@ from typing import Optional
 class Dataset:
     label: str
     backgroundColor: str
-    data: list[Any]
+    data: List[Any]
 
 
 @dataclass
 class ChartData:
-    labels: list[Any]
-    datasets: list[Dataset]
+    labels: List[Any]
+    datasets: List[Dataset]
 
 
 # TODO doesn't handle multiple datasets.
@@ -27,7 +29,7 @@ class LineChart:
         x,  # TODO needs typing
         y,
         backgroundColor: str = "#000000",
-        input_updates: dict[str, Any] = {},
+        input_updates: Dict[str, Any] = {},
     ):
         self.input_name = name
         self.title = title
